interfaces.py
branchtls-sprint
changeset 1006 92a0601b2523
parent 767 b094cf8535b4
parent 994 98f19cf755a1
child 1263 01152fffd593
--- a/interfaces.py	Wed Mar 04 17:09:10 2009 +0100
+++ b/interfaces.py	Wed Mar 04 17:12:28 2009 +0100
@@ -238,7 +238,20 @@
     def rss_feed_url(self):
         """return an url which layout sub-entities item
         """
-class ISIOC(Interface):
-    """interface for entities with sioc views"""
+class ISiocItem(Interface):
+    """interface for entities (which are item
+    in sioc specification) with sioc views"""
     
-   
+    def isioc_content(self):
+        """return content entity"""
+
+    def isioc_container(self):
+        """return container entity"""           
+            
+class ISiocContainer(Interface):
+    """interface for entities (which are container
+    in sioc specification) with sioc views"""
+
+    def isioc_type(self):
+        """return container type (forum, weblog, mailinglist)"""
+